@@ -25,26 +25,14 @@ class RecognizeLicensePlateRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ocr', '2019-12-30', 'RecognizeLicensePlate','ocr')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ImageType(self):
-		return self.get_body_params().get('ImageType')
-
-	def set_ImageType(self,ImageType):
-		self.add_body_params('ImageType', ImageType)
-
-	def get_ImageURL(self):
+	def get_ImageURL(self): # String
 		return self.get_body_params().get('ImageURL')
 
-	def set_ImageURL(self,ImageURL):
+	def set_ImageURL(self, ImageURL):  # String
 		self.add_body_params('ImageURL', ImageURL)
-
-	def get_ImageContent(self):
-		return self.get_body_params().get('ImageContent')
-
-	def set_ImageContent(self,ImageContent):
-		self.add_body_params('ImageContent', ImageContent)
\ No newline at end of file
