@@ -25,16 +25,16 @@ class RecognizeQrCodeRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ocr', '2019-12-30', 'RecognizeQrCode','ocr')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Taskss(self):
+	def get_Taskss(self): # RepeatList
 		return self.get_body_params().get('Tasks')
 
-	def set_Taskss(self, Taskss):
-		for depth1 in range(len(Taskss)):
-			if Taskss[depth1].get('ImageURL') is not None:
-				self.add_body_params('Tasks.' + str(depth1 + 1) + '.ImageURL', Taskss[depth1].get('ImageURL'))
\ No newline at end of file
+	def set_Taskss(self, Tasks):  # RepeatList
+		for depth1 in range(len(Tasks)):
+			if Tasks[depth1].get('ImageURL') is not None:
+				self.add_body_params('Tasks.' + str(depth1 + 1) + '.ImageURL', Tasks[depth1].get('ImageURL'))
