@@ -25,14 +25,14 @@ class RecognizeVINCodeRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ocr', '2019-12-30', 'RecognizeVINCode','ocr')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ImageURL(self):
+	def get_ImageURL(self): # String
 		return self.get_query_params().get('ImageURL')
 
-	def set_ImageURL(self,ImageURL):
-		self.add_query_param('ImageURL',ImageURL)
\ No newline at end of file
+	def set_ImageURL(self, ImageURL):  # String
+		self.add_query_param('ImageURL', ImageURL)
