@@ -25,14 +25,14 @@ class RecognizeVideoCharacterRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ocr', '2019-12-30', 'RecognizeVideoCharacter','ocr')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_VideoURL(self):
+	def get_VideoURL(self): # String
 		return self.get_body_params().get('VideoURL')
 
-	def set_VideoURL(self,VideoURL):
-		self.add_body_params('VideoURL', VideoURL)
\ No newline at end of file
+	def set_VideoURL(self, VideoURL):  # String
+		self.add_body_params('VideoURL', VideoURL)
